using System;
using System.Collections.Generic;
using System.Text;

#if !WINDOWS_PHONE
using NLipsum.Core.Properties;
#else
using NLipsum.WindowsPhone;
#endif

namespace NLipsum.Core {
	/// <summary>
	/// All of these Lipsums are derived from the files at http://lipsum.sourceforge.net/
	/// </summary>
    /// <remarks>Caching added by Dan Clarke</remarks>
	public static class Lipsums {
        private static Dictionary<string, string> _loadedLipsums = new Dictionary<string, string>();

		public static string ChildHarold {
            get { return GetText("ChildHarold"); }
		}

		public static string Decameron {
            get { return GetText("Decameron"); }
		}

		public static string Faust {
            get { return GetText("Faust"); }
		}

		public static string InDerFremde {
            get { return GetText("InDerFremde"); }
		}

		public static string LeBateauIvre {
            get { return GetText("LeBateauIvre"); }
		}

		public static string LeMasque {
            get { return GetText("LeMasque"); }
		}

		public static string LoremIpsum {
            get { return GetText("LoremIpsum"); }
		}

		public static string NagyonFaj {
            get { return GetText("NagyonFaj"); }
		}

		public static string Omagyar {
            get { return GetText("Omagyar"); }
		}

		public static string RobinsonoKruso {
            get { return GetText("RobinsonoKruso"); }
		}

		public static string TheRaven {
            get { return GetText("TheRaven"); }
		}

		public static string TierrayLuna {
            get { return GetText("TierrayLuna"); }
		}

        /// <summary>
        /// Get the text for the specified Lipsum
        /// </summary>
        /// <param name="id">Text name</param>
        /// <returns>Text (Empty string if none available)</returns>
        private static string GetText(string id)
        {
            // Get cached version first if we can
            if (_loadedLipsums.ContainsKey(id))
                return _loadedLipsums[id];

            // No cached version, load the slow way
            string text = string.Empty;

            switch (id)
            {
                case "ChildHarold":
                    text = LipsumUtilities.GetTextFromRawXml(Resources.ChildHarold).ToString();
                    break;

                case "Decameron":
                    text = LipsumUtilities.GetTextFromRawXml(Resources.Decameron).ToString();
                    break;

                case "Faust":
                    text = LipsumUtilities.GetTextFromRawXml(Resources.Faust).ToString();
                    break;

                case "InDerFremde":
                    text = LipsumUtilities.GetTextFromRawXml(Resources.InDerFremde).ToString();
                    break;

                case "LeBateauIvre":
                    text = LipsumUtilities.GetTextFromRawXml(Resources.LeBateauIvre).ToString();
                    break;

                case "LeMasque":
                    text = LipsumUtilities.GetTextFromRawXml(Resources.LeMasque).ToString();
                    break;

                case "NagyonFaj":
                    text = LipsumUtilities.GetTextFromRawXml(Resources.NagyonFaj).ToString();
                    break;

                case "Omagyar":
                    text = LipsumUtilities.GetTextFromRawXml(Resources.Omagyar).ToString();
                    break;

                case "RobinsonoKruso":
                    text = LipsumUtilities.GetTextFromRawXml(Resources.RobinsonoKruso).ToString();
                    break;

                case "TheRaven":
                    text = LipsumUtilities.GetTextFromRawXml(Resources.TheRaven).ToString();
                    break;

                case "TierrayLuna":
                    text = LipsumUtilities.GetTextFromRawXml(Resources.TierrayLuna).ToString();
                    break;

                case "LoremIpsum":
                default:
                    text = LipsumUtilities.GetTextFromRawXml(Resources.LoremIpsum).ToString();
                    break;
            }

            _loadedLipsums[id] = text;
            return text;
        }
	}
}
